# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# The project's page is at http://www.open7x0.org
#

# Put dependencies here all pack should depend on $$(BASE_BUILD_STAGEFILE)
FUSE_DEPS = $(BASE_BUILD_STAGEFILE) $(SIEMENS-LINUX-KERNEL_INSTALLED)

FUSE_VERSION := 2.5.3
FUSE_PATCHES_DIR := $(PATCHES_DIR)/fuse/$(FUSE_VERSION)

FUSE_FILE := fuse-$(FUSE_VERSION).tar.gz
FUSE_DLFILE := $(DOWNLOAD_DIR)/$(FUSE_FILE)
FUSE_URL := http://downloads.sourceforge.net/fuse/$(FUSE_FILE)
FUSE_DIR := $(BUILD_DIR)/fuse-$(FUSE_VERSION)

FUSE_INSTALLED = $(STAGEFILES_DIR)/.fuse_installed

PACKS_RULES_$(CONFIG_FUSE) += $(FUSE_INSTALLED)
FILE_LISTS_$(CONFIG_FUSE) += fuse.lst

CLEAN_RULES += clean-fuse
DISTCLEAN_RULES += distclean-fuse

#
# download fuse
#

$(FUSE_DLFILE): $(TC_INIT_RULE)
	(if [ ! -f $(FUSE_DLFILE) ] ; then \
	$(WGET) $(FUSE_URL) -O $(FUSE_DLFILE) ; \
	fi );
	$(TOUCH) $(FUSE_DLFILE)

#
# unpack fuse
#

$(STAGEFILES_DIR)/.fuse_unpacked: $(FUSE_DLFILE) \
                                           $(wildcard $(FUSE_PATCHES_DIR)/*.patch) \
                                           $$(FUSE_DEPS)
	-$(RM) -rf $(FUSE_DIR)
	$(TAR) -C $(BUILD_DIR) -zf $(FUSE_DLFILE)
	$(TOUCH) $(STAGEFILES_DIR)/.fuse_unpacked

#
# patch fuse
#

$(STAGEFILES_DIR)/.fuse_patched: $(STAGEFILES_DIR)/.fuse_unpacked
	$(call patch_package, $(FUSE_DIR), $(FUSE_PATCHES_DIR))
	$(TOUCH) $(STAGEFILES_DIR)/.fuse_patched

#
# configure fuse
#

$(STAGEFILES_DIR)/.fuse_configured: $(STAGEFILES_DIR)/.fuse_patched
	($(CD) $(FUSE_DIR) ; $(UCLIBC_ENV) \
		$(FUSE_DIR)/configure \
			--target=$(UCLIBC_TARGET) \
			--host=$(TARGET) \
			--build=$(HOST_TARGET) \
			--prefix=/usr \
			--enable-largefile \
			--disable-nls \
			--enable-shared \
			--enable-static \
			--disable-rpath \
			--enable-kernel-module \
			--enable-util \
			--enable-lib \
			--disable-example \
			--disable-auto-modprobe \
			--with-kernel=$(SIEMENS-LINUX-KERNEL_DIR) \
			--disable-mtab)
	$(TOUCH) $(STAGEFILES_DIR)/.fuse_configured

#
# compile fuse
#

$(STAGEFILES_DIR)/.fuse_compiled: $(STAGEFILES_DIR)/.fuse_configured
	$(MAKE) CROSS_COMPILE=$(TARGET)- ARCH=mips \
		PATH="$(PREFIX_BIN):$(PATH)" DESTDIR="$(TARGET_ROOT)/$(M7X0_KERNEL_DIR)" \
		CC=$(EGCS_BIN) -C $(FUSE_DIR) SUBDIRS="kernel" all
	$(MAKE) CROSS_COMPILE=$(TARGET)- ARCH=mips \
		$(UCLIBC_ENV) CFLAGS="$(UCLIBC_CFLAGS) -D_FILE_OFFSET_BITS=64 -DUSE_UCLIBC" \
		DESTDIR="$(TARGET_ROOT)" -C $(FUSE_DIR) SUBDIRS="lib util example" all
	$(TOUCH) $(STAGEFILES_DIR)/.fuse_compiled

#
# install fuse
#

$(STAGEFILES_DIR)/.fuse_installed: $(STAGEFILES_DIR)/.fuse_compiled
	-$(RM) -rf $(TARGET_ROOT)/$(M7X0_KERNEL_DIR)/lib/modules/2.4.21-xfs/kernel/fs/fuse
	$(MKDIR) -p $(TARGET_ROOT)/$(M7X0_KERNEL_DIR)/lib/modules/2.4.21-xfs/kernel/fs/fuse
	$(CP) -f $(FUSE_DIR)/kernel/fuse.o $(TARGET_ROOT)/$(M7X0_KERNEL_DIR)/lib/modules/2.4.21-xfs/kernel/fs/fuse/fuse.o
	$(MAKE) CROSS_COMPILE=$(TARGET)- ARCH=mips \
		$(UCLIBC_ENV) DESTDIR="$(TARGET_ROOT)" \
		-C $(FUSE_DIR) SUBDIRS="lib util" install
	$(MV) $(TARGET_ROOT)/usr/bin/$(UCLIBC_TARGET)-fusermount $(TARGET_ROOT)/usr/bin/fusermount
	$(TOUCH) $(STAGEFILES_DIR)/.fuse_installed


$(FILELIST_DIR)/fuse.lst: $(STAGEFILES_DIR)/.fuse_installed
	$(TOUCH) $(FILELIST_DIR)/fuse.lst

.PHONY: clean-fuse distclean-fuse

clean-fuse:
	-$(RM) -rf $(FUSE_DIR)

#
# clean everthing else
#

distclean-fuse:
	-$(RM) -f $(STAGEFILES_DIR)/.fuse_unpacked
	-$(RM) -f $(STAGEFILES_DIR)/.fuse_patched
	-$(RM) -f $(STAGEFILES_DIR)/.fuse_configured
	-$(RM) -f $(STAGEFILES_DIR)/.fuse_compiled
	-$(RM) -f $(STAGEFILES_DIR)/.fuse_installed
ifeq ($(DISTCLEAN_DLFILE),y)
	-$(RM) -rf $(FUSE_DLFILE)
endif
